@@ -12,7 +12,7 @@
 <?php if(!empty($this->app->user->feedback) or $this->cookie->feedbackView):?>
 <?php $config->global->novice = false; ?>
 <?php $menuGroup = zget($this->lang->menugroup, $this->moduleName);?>
-<?php if($menuGroup != 'oa' and $menuGroup != 'company'):?>
+<?php if($menuGroup != 'oa' and $menuGroup != 'company' and !$this->app->isFlow):?>
 <style>
 #header #subHeader{display:none}
 </style>
