@@ -14,8 +14,11 @@ $(document).ready(function()
     }
 })
 
-function loadPrevData($selector, dataID = 0, element = 'tr')
+function loadPrevData($selector, dataID, element)
 {
+    if(typeof dataID  === 'undefined') dataID  = 0;
+    if(typeof element === 'undefined') element = 'tr';
+  
     var prev   = $selector.data('prev');
     var next   = $selector.data('next');
     var action = $selector.data('action');
