@@ -1,7 +1,7 @@
 <?php if($flow->buildin):?>
 <style>
-#actionList thead tr th:nth-of-type(3){width:50px !important;}
-#actionList thead tr th:nth-of-type(4){width:80px !important;}
+#actionListTable thead tr th:nth-of-type(4){width:50px !important;}
+#actionListTable thead tr th:nth-of-type(5){width:80px !important;}
 </style>
 <?php endif;?>
 <script>
@@ -10,7 +10,6 @@ $('#footer .breadcrumb').append("<li><?php echo $lang->workflowaction->common;?>
 
 $(function()
 {
-    $('#actionList thead tr th:last').width('165');
     var html = $('#actionList tr td.actions a.edit:first').html();
     $('#actionList tr td.actions a.edit').attr('title', html).addClass('btn').html("<i class='icon icon-edit'></i>");
     
