@@ -11,4 +11,4 @@
     <?php echo html::checkbox("fields[$module]", $fields, array_keys($checkedFields), '', 'block');?> 
   </div>
 </div>
-<?php echo html::hidden('module[]', $module);?>
+<?php echo html::hidden('modules[]', $module);?>
